@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::App::Command::dumpwith;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.003001';
 
 # ABSTRACT: Dump all plugins that 'do' a certain role
 
@@ -168,7 +168,7 @@ Dist::Zilla::App::Command::dumpwith - Dump all plugins that 'do' a certain role
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -180,7 +180,36 @@ version 0.003000
 
 If you are using an HTML-enabled POD viewer, you should see a screenshot of this in action:
 
-( Everyone else can visit L<http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/example_01.png> )
+( Everyone else can visit L<http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/0.003000/example_01.png> )
+
+=for html <center>
+  <img src="http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/0.003000/example_01.png"
+       alt="Screenshot"
+       width="740"
+       height="586"/>
+</center>
+
+=head1 DESCRIPTION
+
+This command, like its sibling L<< C<dumpphases>|Dist::Zilla::App::Command::dumpphases >>, exists to help make understanding
+what is going on in C<Dist::Zilla> a little easier.
+
+At least, having this command means debugging certain kinds of problems is more obvious.
+
+If you want to see all plugins that are adding files to your dist?
+
+    dzil dumpwith -- -FileGatherer
+
+Though, of course, this requires some knowledge of what roles are applicable.
+
+If you want to turn colors off, use L<< C<Term::ANSIcolor>'s environment variable|Term::ANSIColor >>
+C<ANSI_COLORS_DISABLED>. E.g.,
+
+    ANSI_COLORS_DISABLED=1 dzil dumpphases
+
+Alternatively, specify a color-free theme:
+
+    dzil dumpwith --color-theme=basic::plain -- -VersionProvider
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -193,13 +222,6 @@ If you are using an HTML-enabled POD viewer, you should see a screenshot of this
 
 =end MetaPOD::JSON
 
-=for html <center>
-  <img src="http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/example_01.png"
-       alt="Screenshot"
-       width="806"
-       height="438"/>
-</center>
-
 =head1 KNOWN ISSUES
 
 Prior to C<Dist::Zilla 6.0>, the format
@@ -223,28 +245,6 @@ Or place all the role names (and only role names) after a C<-->
 Any suggestions welcome for how I can detect this problem case happening and report it,
 but the data appears now outside of a scope I can probe.
 
-=head1 DESCRIPTION
-
-This command, like its sibling L<< C<dumpphases>|Dist::Zilla::App::Command::dumpphases >>, exists to help make understanding
-what is going on in C<Dist::Zilla> a little easier.
-
-At least, having this command means debugging certain kinds of problems is more obvious.
-
-If you want to see all plugins that are adding files to your dist?
-
-    dzil dumpwith -- -FileGatherer
-
-Though, of course, this requires some knowledge of what roles are applicable.
-
-If you want to turn colors off, use L<< C<Term::ANSIcolor>'s environment variable|Term::ANSIColor >>
-C<ANSI_COLORS_DISABLED>. E.g.,
-
-    ANSI_COLORS_DISABLED=1 dzil dumpphases
-
-Alternatively, specify a color-free theme:
-
-    dzil dumpwith --color-theme=basic::plain -- -VersionProvider
-
 =head1 AUTHOR
 
 Kent Fredric <kentnl@cpan.org>
